@@ -16,9 +16,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#if HAVE_CONFIG_H
 #include <config.h>
-#endif /* HAVE_CONFIG_H */
 
 #include <stdio.h>
 #include <ctype.h>
@@ -219,7 +217,6 @@ main(int argc, char *argv[])
 	int no_prompt = 0;
 	int use_encryption = 0;
 	int chained_transactions = 0;
-	const char *display_charset = "";
 	const char *cmdend = "go";
 	int headers = 0;
 	char *columnwidth = NULL;
@@ -269,10 +266,9 @@ main(int argc, char *argv[])
 	char adbuf[512];
 	DBINT convlen;
 	int printedcompute = 0;
-	BYTE *bylist;
-	int nby;
 	char adash;
 	const char *database_name = NULL;
+	int default_exit = EXIT_SUCCESS;
 
 	setlocale(LC_ALL, "");
 
@@ -323,10 +319,6 @@ main(int argc, char *argv[])
 		case 'Y':
 			chained_transactions = 1;
 			break;
-		case 'a':
-			display_charset = optarg;
-			errflg++;
-			break;
 		case 'c':
 			cmdend = optarg;
 			break;
@@ -401,7 +393,7 @@ main(int argc, char *argv[])
 
 	if (errflg) {
 		fprintf(stderr, "usage: fisql [-e] [-F] [-g] [-p] [-n] [-v] [-X] [-Y]\n");
-		fprintf(stderr, "\t[-a display_charset] [-c cmdend] [-D database_name] [-E editor]\n");
+		fprintf(stderr, "\t[-c cmdend] [-D database_name] [-E editor]\n");
 		fprintf(stderr, "\t[-h headers] [-H hostname] [-i inputfile]\n");
 		fprintf(stderr, "\t[-I interfaces_file] [-J client character set]\n");
 		fprintf(stderr, "\t[-l login_timeout] [-m errorlevel]\n");
@@ -539,23 +531,37 @@ main(int argc, char *argv[])
 			if (line == NULL) {
 				line = "exit";
 			}
-			for (cp = line; *cp && isspace((unsigned char) *cp); cp++);
+			for (cp = line; *cp && isspace((unsigned char) *cp); cp++)
+				continue;
 			if (*cp) {
 				add_history(line);
 			}
 			if (!(strncasecmp(line, "!!", 2))) {
+				int rv;
 				cp = line + 2;
-				system(cp);
-				continue;
+				switch (rv = system(cp)) {
+				case 0:
+					continue;
+				case -1:
+					fprintf(stderr,
+					    "Failed to execute `%s'\n", cp);
+					continue;
+				default:
+					fprintf(stderr, "Command `%s' exited "
+					    "with code %d\n", cp, rv);
+					continue;
+				}
 			}
 			/* XXX: isql off-by-one line count error for :r not duplicated */
 			if (!(strncasecmp(line, ":r", 2))) {
-				for (cp = line + 2; *cp && (isspace((unsigned char) *cp)); cp++);
+				for (cp = line + 2; *cp && (isspace((unsigned char) *cp)); cp++)
+					continue;
 				tfn = cp;
-				for (; *cp && !(isspace((unsigned char) *cp)); cp++);
+				for (; *cp && !(isspace((unsigned char) *cp)); cp++)
+					continue;
 				*cp = '\0';
 				if ((fp = fopen(tfn, "r")) == NULL) {
-					printf("Operating system error: Failed to open %s.\n", tfn);
+					fprintf(stderr, "Operating system error: Failed to open %s.\n", tfn);
 					continue;
 				}
 				tmpfp = rl_instream;
@@ -586,7 +592,7 @@ main(int argc, char *argv[])
 			    || (!(strcasecmp(firstword, "quit")))) {
 				reset_term();
 				dbexit();
-				exit(EXIT_SUCCESS);
+				exit(default_exit);
 			}
 			if (!(strcasecmp(firstword, "reset"))) {
 				for (i = 0; i < ibuflines; i++) {
@@ -605,9 +611,12 @@ main(int argc, char *argv[])
 			if ((!(strcasecmp(firstword, "vi")))
 			    || (!(strcasecmp(firstword, editor)))) {
 				int tmpfd;
+				mode_t old_mask;
 
 				strcpy(tmpfn, "/tmp/fisqlXXXXXX");
+				old_mask = umask(0600);
 				tmpfd = mkstemp(tmpfn);
+				umask(old_mask);
 				if ((fp = fdopen(tmpfd, "w")) == NULL) {
 					perror("fisql");
 					reset_term();
@@ -723,10 +732,6 @@ main(int argc, char *argv[])
 								}
 								collen = get_printable_column_size(dbproc, colid);
 								adash = '-';
-								bylist = dbbylist(dbproc, dbrc, &nby);
-								if (nby == 0) {
-									adash = '=';
-								}
 								for (i = 0; i < collen; i++) {
 									putchar(adash);
 								}
@@ -802,6 +807,11 @@ main(int argc, char *argv[])
 					}
 				}
 			}
+		} else {
+			/* Something failed, so change the default
+			 * exit status to reflect that.
+			 */
+			default_exit = EXIT_FAILURE;
 		}
 	}
 	reset_term();
