@@ -19,11 +19,10 @@
  */
 #include "common.h"
 
+#include <freetds/string.h>
 #include <ctype.h>
 #include <assert.h>
-
-static char software_version[] = "$Id: utf8_3.c,v 1.7 2010-12-30 12:04:52 freddy77 Exp $";
-static void *no_unused_var_warn[] = { software_version, no_unused_var_warn };
+#include <replacements.h>
 
 static TDSSOCKET *tds;
 
@@ -42,12 +41,12 @@ test(const char *buf)
 
 	/* do a select and check all results */
 	rc = tds_submit_query(tds, query);
-	if (rc != TDS_SUCCEED) {
+	if (rc != TDS_SUCCESS) {
 		fprintf(stderr, "tds_submit_query() failed\n");
 		exit(1);
 	}
 
-	if (tds_process_tokens(tds, &result_type, NULL, TDS_TOKEN_RESULTS) != TDS_SUCCEED) {
+	if (tds_process_tokens(tds, &result_type, NULL, TDS_TOKEN_RESULTS) != TDS_SUCCESS) {
 		fprintf(stderr, "tds_process_tokens() failed\n");
 		exit(1);
 	}
@@ -57,7 +56,7 @@ test(const char *buf)
 		exit(1);
 	}
 
-	if (tds_process_tokens(tds, &result_type, NULL, TDS_TOKEN_RESULTS) != TDS_SUCCEED) {
+	if (tds_process_tokens(tds, &result_type, NULL, TDS_TOKEN_RESULTS) != TDS_SUCCESS) {
 		fprintf(stderr, "tds_process_tokens() failed\n");
 		exit(1);
 	}
@@ -68,7 +67,7 @@ test(const char *buf)
 	}
 
 	i = 0;
-	while ((rc = tds_process_tokens(tds, &result_type, NULL, TDS_STOPAT_ROWFMT|TDS_STOPAT_DONE|TDS_RETURN_ROW|TDS_RETURN_COMPUTE)) == TDS_SUCCEED) {
+	while ((rc = tds_process_tokens(tds, &result_type, NULL, TDS_STOPAT_ROWFMT|TDS_STOPAT_DONE|TDS_RETURN_ROW|TDS_RETURN_COMPUTE)) == TDS_SUCCESS) {
 
 		TDSCOLUMN *curcol;
 
@@ -77,26 +76,21 @@ test(const char *buf)
 
 		curcol = tds->current_results->columns[0];
 
-		if (strlen(tmp) != curcol->column_namelen || strncmp(tmp, curcol->column_name, curcol->column_namelen) != 0) {
-			int l = curcol->column_namelen;
-
-			if (l > (sizeof(query) -1))
-				l = (sizeof(query) -1);
-			strncpy(query, curcol->column_name, l);
-			query[l] = 0;
-			fprintf(stderr, "Wrong result Got: '%s' len %d\n        Expected: '%s' len %u\n", query,
-				curcol->column_namelen, tmp, (unsigned int) strlen(tmp));
+		if (strcmp(tmp, tds_dstr_cstr(&curcol->column_name)) != 0) {
+			strlcpy(query, tds_dstr_cstr(&curcol->column_name), sizeof(query));
+			fprintf(stderr, "Wrong result Got: '%s' len %u\n        Expected: '%s' len %u\n", query,
+				(unsigned) tds_dstr_len(&curcol->column_name), tmp, (unsigned int) strlen(tmp));
 			exit(1);
 		}
 		++i;
 	}
 
-	if (rc != TDS_SUCCEED || result_type == TDS_ROW_RESULT || result_type == TDS_COMPUTE_RESULT) {
+	if (rc != TDS_SUCCESS || result_type == TDS_ROW_RESULT || result_type == TDS_COMPUTE_RESULT) {
 		fprintf(stderr, "tds_process_tokens() unexpected return\n");
 		exit(1);
 	}
 
-	while ((rc = tds_process_tokens(tds, &result_type, &done_flags, TDS_TOKEN_RESULTS)) == TDS_SUCCEED) {
+	while ((rc = tds_process_tokens(tds, &result_type, &done_flags, TDS_TOKEN_RESULTS)) == TDS_SUCCESS) {
 		switch (result_type) {
 		case TDS_NO_MORE_RESULTS:
 			return;
@@ -126,12 +120,12 @@ main(int argc, char **argv)
 	strcpy(CHARSET, "UTF-8");
 
 	ret = try_tds_login(&login, &tds, __FILE__, verbose);
-	if (ret != TDS_SUCCEED) {
+	if (ret != TDS_SUCCESS) {
 		fprintf(stderr, "try_tds_login() failed\n");
 		return 1;
 	}
 
-	if (IS_TDS7_PLUS(tds)) {
+	if (IS_TDS7_PLUS(tds->conn)) {
 		char buf[129 * 8];
 		int i;
 
